<?php

if (!defined('_PS_VERSION_'))
    exit;


/**
 * Apply minimal purchase constraint to orders based on customer's group
 */
class syMinimalPurchase extends Module {
    
    public function __construct() {
        $this->name = 'syminimalpurchase';
        $this->tab = 'administration';
        $this->version = '1.0';
        $this->author = 'Simone Salerno';

        parent::__construct();

        $this->displayName = $this->l('sy Minimal purchase');
        $this->description = $this->l('Set a minimal purchase for user groups.');
        $this->bootstrap = true;
        $this->id_lang = $this->context->language->id;
    }
    
    public function install() {
        if (!parent::install() || !ConfigurationCore::updateValue($this->name, '{}'))
            return false;
        return true;
    }

    /**
     * Display configuration form
     * @return string
     */
    public function getContent() {
        $response = $this->update();
        
        $this->context->smarty->assign(array(
            'url' => $this->getSelfUrl(),
            'groups' => $this->getGroups(),
            'currency' => $this->context->currency->sign
        ));
        
        return $response . $this->display(__FILE__, 'views/templates/admin/overview.tpl');
    }
    
    /**
     * Add minimal purchase to groups
     * @return array
     */
    protected function getGroups() {
        $groups = Group::getGroups($this->id_lang);
        $minimals = Tools::jsonDecode(Configuration::get($this->name));
        
        array_walk($groups, function(&$group) use ($minimals) {
            $id = $group['id_group'];
            $group['minimal'] = $minimals->{$id};
        });
        
        return $groups;
    }

    /**
     * Get self url for tempalte use
     * @return string
     */
    protected function getSelfUrl() {
        return $_SERVER['REQUEST_URI'];
    }
    
    /**
     * Update db with posted values
     * @return string
     */
    protected function update() {
        if (Tools::isSubmit('syminimalpurchaseupdate')) {
            $POST = filter_input_array(INPUT_POST);
            $values = $POST['values'];
            $post = array();
            
            foreach ($values as $id_group => $minimal) {
                $post[(int)$id_group] = floatval($minimal);
            }
            
            Configuration::updateValue($this->name, Tools::jsonEncode($post));
            
            return $this->displayConfirmation('Updated');
        }
    }
    
}